@@ -114,6 +114,30 @@ class Recipe(zc.recipe.egg.Eggs):
         script.close()
         os.chmod(path, 0755)
 
+    def write_appcfg_script(self, bin, sys_path):
+        """Generates the app configuration script in bin."""
+
+        # Open the destination script file
+        path = os.path.join(self.options['bin-directory'], 'appcfg')
+        script = open(path, 'w')
+
+        # Write script
+        script.write("#!%s\n\n" % 
+                        self.buildout[self.buildout['buildout']['python']]
+                        ['executable'])
+        script.write("import sys\nimport os\n\n")
+        script.write("sys.path[0:0] = [\n")
+        script.write(",\n".join(["  '%s'" % p for p in sys_path]))
+        script.write("\n  ]\n\n")
+        script.write("from appcfg import *\n\n")
+        script.write("if __name__ == '__main__':\n")
+        script.write("  run_file('%s', locals())" % bin)
+
+        # Close script file and modify permissions
+        script.close()
+        os.chmod(path, 0755)
+
+
     def install_appengine(self):
         """Downloads and installs Google App Engine."""
         arch_filename = self.options['url'].split('/')[-1]
@@ -144,12 +168,15 @@ class Recipe(zc.recipe.egg.Eggs):
         if gae is None:
             gae = os.path.join(self.buildout['buildout']['parts-directory'], 
                                'google_appengine')
-
         sys_path = [gae]
-        gae = os.path.join(gae, 'dev_appserver.py')
 
         # Write server script
-        self.write_server_script(self.name, gae, sys_path)
+        gae_server = os.path.join(gae, 'dev_appserver.py')
+        self.write_server_script(self.name, gae_server, sys_path)
+
+        # Write app configuration script
+        gae_config = os.path.join(gae, 'appcfg.py')
+        self.write_appcfg_script(gae_config, sys_path)
 
     def copy_packages(self, ws, lib):
         """Copy egg contents to lib-directory."""
